@@ -488,7 +488,7 @@ __END__
 
 =head1 NAME
 
-Lab::Bus::LinuxGPIB - LinuxGPIB bus
+Lab::Bus::LinuxGPIB - LinuxGPIB bus (deprecated)
 
 =head1 VERSION
 
@@ -510,6 +510,8 @@ or implicit through instrument and connection creation:
 
 =head1 DESCRIPTION
 
+This module belongs to a deprecated legacy module stack, frozen and not under development anymore. Please port your code to the new API; its documentation can be found on the Lab::Measurement homepage, L<https://www.labmeasurement.de/>.
+
 See L<http://linux-gpib.sourceforge.net/> for details on the LinuxGPIB package. The
 package provides both kernel drivers and Perl bindings. Obviously, this will work for Linux systems only. 
 On Windows, please use L<Lab::Bus::VISA>. The interfaces are (errr, will be) identical.
