@@ -97,7 +97,7 @@ __END__
 
 =head1 NAME
 
-Lab::Connection::LinuxGPIB - LinuxGPIB connection
+Lab::Connection::LinuxGPIB - LinuxGPIB connection (deprecated)
 
 =head1 VERSION
 
@@ -116,6 +116,8 @@ $instrument = new HP34401A(
 
 =head1 DESCRIPTION
 
+This module belongs to a deprecated legacy module stack, frozen and not under development anymore. Please port your code to the new API; its documentation can be found on the Lab::Measurement homepage, L<https://www.labmeasurement.de/>.
+
 C<Lab::Connection::LinuxGPIB> provides a GPIB-type connection with the bus L<Lab::Bus::LinuxGPIB>,
 using L<Linux GPIB (aka libgpib0 in debian)|http://linux-gpib.sourceforge.net/> as backend.
 
