@@ -46,7 +46,7 @@ __END__
 
 =head1 NAME
 
-Lab::Connection::VISA - VISA-type connection
+Lab::Connection::VISA - VISA-type connection (deprecated)
 
 =head1 VERSION
 
@@ -66,6 +66,8 @@ $instrument = new HP34401A(
 
 =head1 DESCRIPTION
 
+This module belongs to a deprecated legacy module stack, frozen and not under development anymore. Please port your code to the new API; its documentation can be found on the Lab::Measurement homepage, L<https://www.labmeasurement.de/>.
+
 C<Lab::Connection::VISA> provides a VISA-type connection with L<Lab::Bus::VISA> using 
 NI VISA (L<Lab::VISA>) as backend.
 
