@@ -98,7 +98,7 @@ __END__
 
 =head1 NAME
 
-Lab::XPRESS::Sweep::Frequency - Frequency sweep
+Lab::XPRESS::Sweep::Frequency - Frequency sweep (deprecated)
 
 =head1 VERSION
 
@@ -129,6 +129,8 @@ version 3.899
 
 =head1 DESCRIPTION
 
+This module belongs to a deprecated legacy module stack, frozen and not under development anymore. Please port your code to the new API; its documentation can be found on the Lab::Measurement homepage, L<https://www.labmeasurement.de/>.
+
 Parent: Lab::XPRESS::Sweep
 
 The Lab::XPRESS::Sweep::Frequency class implements a module for frequncy sweeps in the Lab::XPRESS::Sweep framework.
