@@ -165,7 +165,7 @@ __END__
 
 =head1 NAME
 
-Lab::XPRESS::Sweep::Voltage - Voltage sweep
+Lab::XPRESS::Sweep::Voltage - Voltage sweep (deprecated)
 
 =head1 VERSION
 
@@ -195,6 +195,8 @@ version 3.899
 
 =head1 DESCRIPTION
 
+This module belongs to a deprecated legacy module stack, frozen and not under development anymore. Please port your code to the new API; its documentation can be found on the Lab::Measurement homepage, L<https://www.labmeasurement.de/>.
+
 Parent: Lab::XPRESS::Sweep
 
 The Lab::XPRESS::Sweep::Voltage class implements a module for voltage Sweeps in the Lab::XPRESS::Sweep framework.
